@@ -1,10 +1,8 @@
 # SPDX-FileCopyrightText: 2017-2022 Contributors to the OpenSTEF project <korte.termijn.prognoses@alliander.com> # noqa E501>
 #
 # SPDX-License-Identifier: MPL-2.0
+"""Tracy checks the mysql todolist and tries her best to execute the functions with desired inputs.
 
-"""run_tracy.py
-Tracy checks the mysql todolist and tries her best to execute the
-functions with desired inputs
 This scripts works as follows:
   1. Checks the mysql table 'todolist' for jobs (which are not already in progress and
     which are not already failed)
@@ -24,9 +22,8 @@ Example:
 
     Alternatively this code can be run directly by running::
         $ python run_tracy.py
-Attributes:
-"""
 
+"""
 # sql to create the Tracy jobs table (todolist)
 
 # CREATE TABLE IF NOT EXISTS `tst_icarus`.`todolist` (
@@ -37,9 +34,10 @@ Attributes:
 # `inprogress` BOOLEAN NULL DEFAULT NULL ,
 # PRIMARY KEY (`id`), UNIQUE `id` (`id`))
 # ENGINE = InnoDB;
-
 from pathlib import Path
+from typing import Dict
 
+from openstef.data_classes.prediction_job import PredictionJobDataClass
 from openstef.enums import TracyJobResult
 from openstef.monitoring import teams
 from openstef.tasks.optimize_hyperparameters import optimize_hyperparameters_task
@@ -47,7 +45,7 @@ from openstef.tasks.train_model import train_model_task
 from openstef.tasks.utils.taskcontext import TaskContext
 
 
-def run_tracy(context):
+def run_tracy(context: TaskContext) -> None:
     # Get all Tracy jobs
     tracy_jobs = context.database.ktp_api.get_all_tracy_jobs(inprogress=0)
     num_jobs = len(tracy_jobs)
@@ -93,7 +91,20 @@ def run_tracy(context):
     context.logger.info("Finished processing all Tracy jobs - Tracy out!")
 
 
-def run_tracy_job(job, pj, context):
+def run_tracy_job(
+    job: Dict, pj: PredictionJobDataClass, context: TaskContext
+) -> TracyJobResult:
+    """Run tracy job.
+
+    Args:
+        job: Tracy jon
+        pj: Prediction job
+        context: Task context.
+
+    Returns:
+        Result of the Tracy job.
+
+    """
     # Try to process Tracy job
     try:
         # If train model job (TODO remove old name when jobs are done)
