@@ -2,10 +2,9 @@
 #
 # SPDX-License-Identifier: MPL-2.0
 
-"""split_forecast.py
+"""This module contains the CRON job that is periodically executed to make prognoses of solar features.
 
-This module contains the CRON job that is periodically executed to make
-prognoses of solar features. These features are usefull for splitting the load
+These features are usefull for splitting the load
 in solar and wind contributions.
 This is achieved by carrying out the folowing steps:
   1. Get the wind and solar reference data for the specific location of the
@@ -22,11 +21,8 @@ Example:
 
         $ python split_forecast.py
 
-Attributes:
-
-
 """
-
+from typing import Dict, Tuple
 from datetime import datetime
 from pathlib import Path
 
@@ -65,15 +61,15 @@ def main(config=None, database=None):
 def split_forecast_task(
     pj: PredictionJobDataClass,
     context: TaskContext,
-):
-    """Function that caries out the energy splitting for a specific prediction job with
-    id pid.
+) -> pd.DataFrame:
+    """Function that caries out the energy splitting for a specific prediction job with id pid.
 
     Args:
-        pid (int): Prediction job id
+        pid: Prediction job id
 
     Returns:
-        pandas.DataFrame: Energy splitting coefficients.
+        Energy splitting coefficients.
+
     """
     logger = structlog.get_logger(__name__)
 
@@ -124,17 +120,20 @@ def split_forecast_task(
         return coefsdf
 
 
-def determine_invalid_coefs(new_coefs, last_coefs):
+def determine_invalid_coefs(
+    new_coefs: pd.DataFrame, last_coefs: pd.DataFrame
+) -> pd.DataFrame:
     """Determine which new coefficients are valid and return them.
 
     Args:
-        new_coefs (pd.DataFrame): df of new coefficients for standard load
+        new_coefs: df of new coefficients for standard load
             profiles (i.e. wind, solar, household)
-        last_coefs (pd.DataFrame): df of last coefficients for standard load
+        last_coefs: df of last coefficients for standard load
             profiles (i.e. wind, solar, household)
 
     Returns:
-        pd.DataFrame: df of invalid coefficients
+        Dataframe with invalid coefficients
+
     """
     merged_coefs = pd.merge(
         last_coefs, new_coefs, on="coef_name", how="left", suffixes=["_last", "_new"]
@@ -157,18 +156,20 @@ def determine_invalid_coefs(new_coefs, last_coefs):
     return invalid_coefs
 
 
-def convert_coefdict_to_coefsdf(pj, input_split_function, coefdict):
-    """Convert dictionary of coefficients to dataframe with additional data for db
-    storage.
+def convert_coefdict_to_coefsdf(
+    pj: PredictionJobDataClass, input_split_function: pd.DataFrame, coefdict: Dict
+) -> pd.DataFrame:
+    """Convert dictionary of coefficients to dataframe with additional data for db storage.
 
     Args:
-        pj (PredictionJobDataClass): prediction job
-        input_split_function (pd.DataFrame): df of columns of standard load profiles,
+        pj: prediction job
+        input_split_function: df of columns of standard load profiles,
             i.e. wind, solar, household
-        coefdict (dict): dict of coefficient per standard load profile
+        coefdict: dict of coefficient per standard load profile
 
     Returns:
-        pd.DataFrame: df of coefficients to insert in sql
+        DataFrame of coefficients to insert in sql
+
     """
     #
     sql_column_labels = ["pid", "date_start", "date_end", "created"]
@@ -187,20 +188,22 @@ def convert_coefdict_to_coefsdf(pj, input_split_function, coefdict):
     return coefsdf
 
 
-def find_components(df, zero_bound=True):
-    """Function that does the actual energy splitting
+def find_components(
+    df: pd.DataFrame, zero_bound: bool = True
+) -> Tuple[pd.DataFrame, Dict]:
+    """Function that does the actual energy splitting.
 
     Args:
-        df (pandas.DataFrame): Input data. The dataframe should contain these columns
+        df: Input data. The dataframe should contain these columns
             in exactly this order: [load, wind_ref, pv_ref, mulitple tdcv colums]
-        zero_bound (bool): If zero_bound is True coefficients can't be negative.
+        zero_bound: If zero_bound is True coefficients can't be negative.
 
     Returns:
         tuple:
-            [0] pandas.DataFrame: Containing the wind and solar components
-            [1] dict: The coefficients that result from the fitting
-    """
+            - DataFrame containing the wind and solar components
+            - Dict with the coefficients that result from the fitting
 
+    """
     # Define function to fit
     def weighted_sum(x, *args):
         if len(x) != len(args):
