@@ -1,12 +1,9 @@
 # SPDX-FileCopyrightText: 2017-2022 Contributors to the OpenSTEF project <korte.termijn.prognoses@alliander.com> # noqa E501>
 #
 # SPDX-License-Identifier: MPL-2.0
+"""This module contains the CRON job that is periodically executed to retrain the prognosis models.
 
-# -*- coding: utf-8 -*-
-"""model_train.py
-
-This module contains the CRON job that is periodically executed to retrain the
-prognosis models. For this the folowing steps are caried out:
+For this the folowing steps are caried out:
   1. Get historic training data (TDCV, Load, Weather and APX price data)
   2. Apply features
   3. Train and Test the new model
@@ -50,10 +47,13 @@ def train_model_task(
     Expected prediction job keys:  "id", "model", "lat", "lon", "name"
 
     Args:
-        pj (PredictionJobDataClass): Prediction job
-        context (TaskContext): Contect object that holds a config manager and a
+        pj: Prediction job
+        context: Contect object that holds a config manager and a
             database connection.
-        check_old_model_age (bool): check if model is too young to be retrained
+        check_old_model_age: check if model is too young to be retrained
+        datetime_start: Start
+        datetime_end: End
+
     """
     # Get the paths for storing model and reports from the config manager
     mlflow_tracking_uri = context.config.paths.mlflow_tracking_uri
@@ -103,7 +103,6 @@ def train_model_task(
 
 
 def main(model_type=None, config=None, database=None):
-
     if database is None or config is None:
         raise RuntimeError(
             "Please specifiy a configmanager and/or database connection object. These"
