@@ -1,70 +1,76 @@
-# SPDX-FileCopyrightText: 2017-2021 Contributors to the OpenSTF project <korte.termijn.prognoses@alliander.com> # noqa E501>
+# SPDX-FileCopyrightText: 2017-2022 Contributors to the OpenSTEF project <korte.termijn.prognoses@alliander.com> # noqa E501>
 #
 # SPDX-License-Identifier: MPL-2.0
-
+from typing import Callable
 import traceback
 
 import structlog
-from openstef_dbc.config.config import ConfigManager
-from openstef_dbc.database import DataBase
 
 from openstef.monitoring.performance_meter import PerformanceMeter
 from openstef.monitoring.teams import post_teams
-from openstef.tasks.utils.predictionjobloop import PredictionJobException
+from openstef.exceptions import PredictionJobException
 
 
 class TaskContext:
-    def __init__(
-        self,
-        name,
-        suppress_exceptions=False,
-        post_teams_on_exception=True,
-        on_exception=None,
-        on_successful=None,
-        on_end=None,
-    ):
-        """A context manager that can be used to run tasks with.
+    """A context manager that can be used to run tasks with.
+
+    Should be used as:
+
+    .. code-block:: py
 
-        Should be used as:
         with TaskContext("my_task_name") as context:
             pass
 
-        Args:
-            name (string): Name of the task
-            suppress_exceptions (bool, optional): If set to False the context
-                manager will pass any raised exception on. Defaults to False.
-            post_teams_on_exception (bool, optional): If set to True the context
-                manager will automatically post a message to teams when an
-                exception is encountered. Defaults to True.
-            on_exception (callable, optional): Callback, will be called
-                when an exception is raised. Callable gets exc_type, exc_info,
-                stack_info as arguments.
-            on_successful (callable, optional): Callback, will be called
-                everytime if the task is successful (no exception is raised).
-            on_end (callable, optional): Callback, will be called if the task is
-                completed. Callable gets a bool indicating success as argument.
-        """
+    Args:
+        name: Name of the task
+        config: Configuration object, can be found in openSTEF-dbc
+        database: Database object, can be found in openSTEF-dbc
+        suppress_exceptions: If set to False the context
+            manager will pass any raised exception on. Defaults to False.
+        post_teams_on_exception: If set to True the context
+            manager will automatically post a message to teams when an
+            exception is encountered. Defaults to True.
+        on_exception : Callback, will be called
+            when an exception is raised. Callable gets exc_type, exc_info,
+            stack_info as arguments.
+        on_successful: Callback, will be called
+            everytime if the task is successful (no exception is raised).
+        on_end: Callback, will be called if the task is
+            completed. Callable gets a bool indicating success as argument.
+
+    """
+
+    def __init__(
+        self,
+        name: str,
+        config: object,
+        database: object,
+        suppress_exceptions: bool = False,
+        post_teams_on_exception: bool = True,
+        on_exception: Callable = None,
+        on_successful: Callable = None,
+        on_end: Callable = None,
+    ):
+        """Initialize context manager."""
         self.name = name
         self.suppress_exceptions = suppress_exceptions
         self.post_teams_on_exception = post_teams_on_exception
         self.on_exception = on_exception
         self.on_successful = on_successful
         self.on_end = on_end
+        self.config = config
+        self.database = database
 
     def __enter__(self):
-        self.config = ConfigManager.get_instance()
-
         self.logger = structlog.get_logger(__name__).bind(task=self.name)
 
-        self.database = DataBase(self.config)
-
         self.perf_meter = PerformanceMeter(self.logger)
 
         self.perf_meter.start_level("task", self.name)
 
         return self
 
-    def __exit__(self, exc_type, exc_info, stack_info):
+    def __exit__(self, exc_type: type, exc_info: str, stack_info: str) -> bool:
         self.successful = exc_type is None
 
         if self.successful:
@@ -90,7 +96,9 @@ class TaskContext:
         # Returning true stops the propagation of the exception
         return self.suppress_exceptions
 
-    def _send_teams_message(self, exc_type, exc_info, stack_info):
+    def _send_teams_message(
+        self, exc_type: type, exc_info: str, stack_info: str
+    ) -> None:
         stack_text = "".join(traceback.format_exception(exc_type, exc_info, stack_info))
         # The teams webhook behaves weird. Using the correct order \r\n does NOT work
         # The 4 spaces forces teams to format a monospaced message for some reason
@@ -140,4 +148,6 @@ class TaskContext:
             }
         )
 
-        post_teams(msg)
+        post_teams(
+            msg, url=self.config.teams.monitoring_url, proxies=self.config.proxies
+        )
